# dmario24_plus
- Add two integers

### USE
```
$ pip install dmario24_plus
$ python
Python 3.9.19 (main, Jul 15 2024, 12:30:09)
[GCC 11.4.0] on linux
Type "help", "copyright", "credits" or "license" for more information.
>>> from dmario24_plus.cal import plus
>>> plus(1, 10)
11
```
